@@ -6,15 +6,15 @@ Created on Sat Oct 24 18:24:20 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.1'
-__release__ = 20230106
-__all__ = ['units', 'convert']
+__version__ = '0.5.4'
+__release__ = 2023012
+__all__ = ['units', 'convert', 'Unit', 'is_Unit']
 
 import unyts.parameters
 from .parameters import print_path, reload, raise_error, cache
 from .units.define import units
 from .converter import convert
-from .unit_class import Unit
+from .unit_class import Unit, is_Unit
 
 if unyts.parameters.unyts_parameters_.show_version_:
     print("loaded unyts version", __version__)
