@@ -6,8 +6,8 @@ Created on Sat Oct 24 15:57:27 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.1'
-__release__ = 20230106
+__version__ = '0.5.3'
+__release__ = 20230108
 __all__ = ['convert', 'convertible']
 
 from unyts.database import unitsNetwork
@@ -403,8 +403,14 @@ def convert(value: numeric, from_unit: str, to_unit: str, print_conversion_path:
     return conv
 
 
-def convert_for_SimPandas(value, from_unit, to_unit):
+def convert_for_SimPandas(value: numeric, from_unit: str, to_unit: str, print_conversion_path: bool = False):
     conv = None
+    print_conversion_path = bool(print_conversion_path)
     if convertible(from_unit, to_unit):
         conv, conv_path = _converter(value, from_unit, to_unit)
+    if print_conversion_path and conv is not None:
+        print("converting from '" + str(from_unit) + "' to '" + str(to_unit),
+              print_path(conv_path), sep='\n')
+    elif print_conversion_path and conv is not None:
+        warn("conversion not found, returning original values.")
     return value if conv is None else conv
