@@ -6,8 +6,8 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.4.9'
-__release__ = 20221231
+__version__ = '0.5.2'
+__release__ = 20230107
 __all__ = ['Time']
 
 from unyts.dictionaries import dictionary
@@ -18,7 +18,7 @@ from unyts.helpers.common_classes import unit_or_str, numeric
 class Time(Unit):
     classUnits = dictionary['Time']
 
-    def __init__(self, value: numeric, units: unit_or_str) -> Unit:
+    def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'time'
         self.kind = Time
         self.value = self.check_value(value)
